@@ -1,5 +1,6 @@
 #![forbid(unsafe_code)]
 #![deny(
+    clippy::dbg_macro,
     missing_copy_implementations,
     rustdoc::missing_crate_level_docs,
     missing_debug_implementations,
@@ -22,7 +23,7 @@ use trillium_router::{Router, RouterConnExt};
 let router = Router::new()
     .get("/", |conn: Conn| async move { conn.ok("you have reached the index") })
     .get("/pages/:page_name", |conn: Conn| async move {
-        let page_name = conn_unwrap!(conn, conn.param("page_name"));
+        let page_name = conn_unwrap!(conn.param("page_name"), conn);
         let content = format!("you have reached the page named {}", page_name);
         conn.ok(content)
     });
@@ -80,7 +81,7 @@ use trillium_router::{routes, RouterConnExt};
 let router = routes!(
     get "/" |conn: Conn| async move { conn.ok("you have reached the index") },
     get "/pages/:page_name" |conn: Conn| async move {
-        let page_name = conn_unwrap!(conn, conn.param("page_name"));
+        let page_name = conn_unwrap!(conn.param("page_name"), conn);
         let content = format!("you have reached the page named {}", page_name);
         conn.ok(content)
     }
